package com.ruoyi.oa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.oa.mapper.CmcSettleSummaryMapper;
import com.ruoyi.oa.domain.CmcSettleSummary;
import com.ruoyi.oa.service.ICmcSettleSummaryService;

/**
 * cmc结算汇总Service业务层处理
 * 
 * @author cmc
 * @date 2024-04-29
 */
@Service
public class CmcSettleSummaryServiceImpl implements ICmcSettleSummaryService 
{
    @Autowired
    private CmcSettleSummaryMapper cmcSettleSummaryMapper;

    /**
     * 查询cmc结算汇总
     * 
     * @param settleId cmc结算汇总主键
     * @return cmc结算汇总
     */
    @Override
    public CmcSettleSummary selectCmcSettleSummaryBySettleId(String settleId)
    {
        return cmcSettleSummaryMapper.selectCmcSettleSummaryBySettleId(settleId);
    }

    /**
     * 查询cmc结算汇总列表
     * 
     * @param cmcSettleSummary cmc结算汇总
     * @return cmc结算汇总
     */
    @Override
    public List<CmcSettleSummary> selectCmcSettleSummaryList(CmcSettleSummary cmcSettleSummary)
    {
        return cmcSettleSummaryMapper.selectCmcSettleSummaryList(cmcSettleSummary);
    }

    /**
     * 新增cmc结算汇总
     * 
     * @param cmcSettleSummary cmc结算汇总
     * @return 结果
     */
    @Override
    public int insertCmcSettleSummary(CmcSettleSummary cmcSettleSummary)
    {
        return cmcSettleSummaryMapper.insertCmcSettleSummary(cmcSettleSummary);
    }

    /**
     * 修改cmc结算汇总
     * 
     * @param cmcSettleSummary cmc结算汇总
     * @return 结果
     */
    @Override
    public int updateCmcSettleSummary(CmcSettleSummary cmcSettleSummary)
    {
        return cmcSettleSummaryMapper.updateCmcSettleSummary(cmcSettleSummary);
    }

    /**
     * 批量删除cmc结算汇总
     * 
     * @param settleIds 需要删除的cmc结算汇总主键
     * @return 结果
     */
    @Override
    public int deleteCmcSettleSummaryBySettleIds(String[] settleIds)
    {
        return cmcSettleSummaryMapper.deleteCmcSettleSummaryBySettleIds(settleIds);
    }

    /**
     * 删除cmc结算汇总信息
     * 
     * @param settleId cmc结算汇总主键
     * @return 结果
     */
    @Override
    public int deleteCmcSettleSummaryBySettleId(String settleId)
    {
        return cmcSettleSummaryMapper.deleteCmcSettleSummaryBySettleId(settleId);
    }
}
